SystemOrganization addCategory: #'Seaside-Development-Core'!
SystemOrganization addCategory: #'Seaside-Development-Filter'!
SystemOrganization addCategory: #'Seaside-Development-Plugins'!

!WAPackage class methodsFor: '*seaside-development' stamp: 'jf 1/11/2009 14:30'!
seasideDevelopment
	^ self new
		name: 'Seaside-Development';
		description: 'Web-based development tools and debugging support.';
		addDependency: 'Seaside-WebTools';
		yourself! !

WAErrorHandler subclass: #WADebugErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADebugErrorHandler commentStamp: 'pmm 5/27/2007 21:47' prior: 0!
I am like WAErrorHandler except that I open a debugger in the image for errors and warnings (not for internal errors).!

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 11/12/2008 01:58'!
debugAndResume: anException
	self open: anException.

	"If the user closes the debugger, the process is terminated and the stack unwound.
	There was previously an #ifCurtailed: block around the #open: call above to try to
	catch the process termination so we could display a nice error page but this also
	ended up being called when the user restarted a context in the debugger.
	
	If they Proceed in the debugger, behaviour is platform-dependent. Currently, VW
	should resume the signaling context, so this method will not continue past the call
	to #open:. Squeak currently resumes the context that opened the Debugger, which
	results in the call to #open: returning."

	^ anException isResumable
		ifTrue: [ anException resume ]
		ifFalse: [ self unableToResumeResponse ]! !

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 9/19/2008 19:45'!
handleDefault: anException
	^ self debugAndResume: anException! !

!WADebugErrorHandler methodsFor: 'actions' stamp: 'jf 1/22/2009 02:43'!
open: anException
	WAPlatform current openDebuggerOn: anException! !

!WADebugErrorHandler methodsFor: 'content' stamp: 'jf 9/14/2008 15:35'!
unableToResumeResponse
	| content |
	content := WARenderCanvas builder
		fullDocument: true;
		rootBlock: [ :root | root title: 'Unable to proceed' ];
		render: [ :html |
			html heading level1; with: 'Unable to proceed - hit Refresh to retry'.
			html paragraph: 'Some exceptions cannot be resumed. You will usually see this page if you hit Proceed while debugging one of these exceptions. Your request was aborted but you can retry it by refreshing the page.' ].
	
	^ WAResponse new
		internalError;
		nextPutAll: content;
		yourself! !

WADebugErrorHandler subclass: #WAWalkbackErrorHandler
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAWalkbackErrorHandler commentStamp: 'jf 10/27/2008 22:44' prior: 0!
I am the default development error handler that displays the stack frames and adds the option to display a debugger.

I delegate the rendering to WAWalkback.

This handler uses Components and depends on having a valid Session. If an error occurs outside of the Session scope it will simply use the superclass behaviour, which should be to open a debugger.!

!WAWalkbackErrorHandler methodsFor: 'private' stamp: 'lr 2/3/2009 21:13'!
open: anException 
	| answer |
	self requestContext request isXmlHttpRequest ifTrue: [ ^ super open: anException ].

	"If an error occurs trying to display the walkback component, we just use the super
	behaviour, which should be to open a debugger.."
	answer := 
	[ self session isNil or: 
		[ self session inNewRenderLoopCall: (WAPlatform current walkbackClass exception: anException) ] ] 
		on: Error
		do: [ :err | true ].
	answer ifTrue: [ super open: anException ]! !

WALabelledFormDialog subclass: #WAViewer
	instanceVariableNames: 'presenter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAViewer class methodsFor: 'instance creation' stamp: 'avi 3/13/2004 01:13'!
on: aPresenter
	^ self new presenter: aPresenter! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
buttons
	^ #(save)! !

!WAViewer methodsFor: 'actions' stamp: 'jf 1/22/2009 02:43'!
compile: aString
	WAPlatform current
		compile: aString
		into: presenter class
		classified: #rendering! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
model
	^ presenter! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:13'!
presenter: aPresenter
	presenter := aPresenter! !

!WAViewer methodsFor: 'rendering' stamp: 'lr 8/30/2008 16:22'!
renderContentOn: html 
	html heading
		level3;
		with: presenter seasideString.
	super renderContentOn: html! !

!WAViewer methodsFor: 'rendering' stamp: 'pmm 7/28/2007 10:27'!
renderCssOn: html
	html textArea
		rows: 20;
		columns: 80;
		value: presenter style;
		callback: [ :css | self compile: 'style ^ ', css printString]! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:14'!
rows
	^ #(css)! !

!WAViewer methodsFor: 'actions' stamp: 'lr 10/28/2007 14:42'!
save! !

!WAViewer methodsFor: 'accessing' stamp: 'avi 3/13/2004 01:22'!
script
	^ 'self.opener.location=self.opener.location'! !

WADecoration subclass: #WAToolDecoration
	instanceVariableNames: 'plugins showHalos'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAToolDecoration class methodsFor: 'testing' stamp: 'lr 9/14/2008 12:54'!
canBeRoot
	^ true! !

!WAToolDecoration methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:26'!
initialize
	super initialize.
	showHalos := WAValueHolder with: false! !

!WAToolDecoration methodsFor: 'testing' stamp: 'lr 1/3/2008 13:15'!
isGlobal
	^ true! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 2/7/2009 16:57'!
plugins
	^ plugins! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'jf 11/3/2008 22:28'!
renderChildOn: html
	self showHalos
		ifTrue: [ html context debugMode ].
	self renderNextOn: html.
	html context clearMode! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'lr 10/28/2007 14:42'!
renderContentOn: html
	self renderChildOn: html.
	self renderToolbarOn: html! !

!WAToolDecoration methodsFor: 'rendering' stamp: 'lr 9/25/2008 10:40'!
renderToolbarOn: html
	html div id: 'toolbar'; with: [
		(self plugins select: [ :each | each isActive ])
			do: [ :each | html render: each ]
			separatedBy: [ html text: ' ' ] ]! !

!WAToolDecoration methodsFor: 'initialization' stamp: 'lr 2/7/2009 17:01'!
setNext: aDecoration
	super setNext: aDecoration.
	plugins := WAToolPlugin allSubclassesOn: self component for: self! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 6/5/2007 21:46'!
showHalos
	^ showHalos contents! !

!WAToolDecoration methodsFor: 'accessing' stamp: 'lr 4/15/2007 18:46'!
states
	^ Array with: showHalos! !

!WAToolDecoration methodsFor: 'plugin-halos' stamp: 'lr 3/24/2008 11:20'!
toggleHalos
	showHalos contents: showHalos contents not! !

!WAToolDecoration methodsFor: 'updating' stamp: 'MAD 8/29/2008 18:02'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	WADevelopmentFiles default updateRoot: anHtmlRoot! !

WAHtmlDocument subclass: #WAPrettyPrintedDocument
	instanceVariableNames: 'html indentLevel indentCloseTags firstLine'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAPrettyPrintedDocument class methodsFor: 'instance creation' stamp: 'jf 1/30/2009 20:48'!
context: aRenderContext
	^ self basicNew initializeWithRenderer: (WAHtmlCanvas context: aRenderContext); yourself! !

!WAPrettyPrintedDocument class methodsFor: 'deprecated' stamp: 'jf 1/30/2009 20:57'!
renderer: aRenderer
	self	seasideDeprecatedApi: 'WAPrettyPrintedDocument class>>#renderer:'
		details: 'Use WAPrettyPrintedDocument class>>#context:.'.
		
	^ self context: aRenderer context! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'pmm 8/31/2008 14:46'!
attribute: aKey with: aValue 
	aValue == false ifTrue: [ ^ self ].
	html space.
	html span
		class: (self cssClassForAttribute: aKey);
		with: aKey.
	html text: '='.
	html span
		class: 'attribute-value';
		with: [
			html text: '"'.
			(self knownRefs includes: aKey) 
				ifTrue: [
					html anchor
						url: aValue seasideString;
						with: aValue ]
				ifFalse: [
					(self knownEvents includes: aKey) 
						ifTrue: [
							html anchor
								onClick: aValue;
								with: aValue ]
						ifFalse: [
							aValue == true 
								ifTrue: [ html text: aKey ]
								ifFalse: [ html render: aValue ] ] ].
			html text: '"' ]! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 4/20/2007 22:11'!
attributes: anAttributes
	anAttributes ifNil: [ ^ self ].
	anAttributes keysAndValuesDo: [ :key :value | self attribute: key with: value ]! !

!WAPrettyPrintedDocument methodsFor: 'actions' stamp: 'jf 1/30/2009 20:50'!
close: anHtmlRoot
	super close: anHtmlRoot.
	html flush! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 10/28/2007 14:42'!
closeTag: aString
	indentLevel := indentLevel - 1.
	indentCloseTags removeLast
		ifTrue: [ self indent ].
	html text: '</'.
	html span class: (self cssClassFor: aString); with: aString.
	html text: '>'! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:13'!
cssClassFor: aString
	^ (self knownTags includes: aString)
		ifTrue: [ 'tag-known' ]
		ifFalse: [ 'tag-unknown' ]! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:13'!
cssClassForAttribute: aString
	^ (self knownAttributes includes: aString)
		ifTrue: [ 'attribute-known' ]
		ifFalse: [ 'attribute-unknown' ]! !

!WAPrettyPrintedDocument methodsFor: 'accessing' stamp: 'lr 3/26/2007 22:28'!
document
	^ html document! !

!WAPrettyPrintedDocument methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:39'!
htmlEncoder
	^ self document htmlEncoder! !

!WAPrettyPrintedDocument methodsFor: 'private' stamp: 'lr 4/20/2007 22:29'!
indent
	firstLine
		ifTrue: [ firstLine := false ]
		ifFalse: [ html break ].
	indentLevel timesRepeat: [ html space: 2 ]! !

!WAPrettyPrintedDocument methodsFor: 'initialization' stamp: 'jf 1/23/2009 23:24'!
initializeWithRenderer: aRenderer
	self initializeWithStream: nil codec: nil.
	html := aRenderer.
	indentCloseTags := OrderedCollection with: false.
	indentLevel := 0.
	firstLine := true! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 22:05'!
knownAttributes
	^ #('abbr' 'accept' 'accept' 'accesskey' 'action' 'align' 'alink' 'alt' 'archive' 'axis' 'background' 'bgcolor' 'bgproperties' 'border' 'cellpadding' 'cellspacing' 'char' 'charoff' 'charset' 'charset' 'checked' 'cite' 'class' 'classid' 'clear' 'code' 'codebase' 'codetype' 'color' 'cols' 'colspan' 'compact' 'content' 'coords' 'data' 'datetime' 'declare' 'defer' 'dir' 'direction' 'disabled' 'encoding' 'enctype' 'equiv' 'face' 'for' 'frame' 'frameborder' 'framespacing' 'gutter' 'headers' 'height' 'href' 'hreflang' 'hspace' 'http' 'id' 'ismap' 'label' 'lang' 'leftmargin' 'link' 'longdesc' 'loop' 'lowsrc' 'marginheight' 'marginwidth' 'maxlength' 'media' 'method' 'methods' 'multiple' 'name' 'nohref' 'noresize' 'noshade' 'nowrap' 'object' 'onabort' 'onblur' 'onchange' 'onclick' 'ondblclick' 'onerror' 'onfocus' 'onkeydown' 'onkeypress' 'onkeyup' 'onload' 'onmousedown' 'onmousemove' 'onmouseout' 'onmouseover' 'onmouseup' 'onreset' 'onselect' 'onsubmit' 'onunload' 'prompt' 'readonly' 'rel' 'rev' 'rows' 'rowspan' 'rules' 'scheme' 'scope' 'scrolling' 'selected' 'shape' 'size' 'span' 'src' 'standby' 'style' 'summary' 'tabindex' 'target' 'text' 'title' 'type' 'urn' 'usemap' 'valign' 'value' 'valuetype' 'version' 'vlink' 'vspace' 'width' 'wrap' 'xml:lang' 'xmlns')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 5/11/2007 11:13'!
knownEvents
	^ #('onabort' 'onblur' 'onchange' 'onclick' 'ondblclick' 'onerror' 'onfocus' 'onkeydown' 'onkeypress' 'onkeyup' 'onload' 'onmousedown' 'onmousemove' 'onmouseout' 'onmouseover' 'onmouseup' 'onreset' 'onselect' 'onsubmit' 'onunload')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 22:11'!
knownRefs
	^ #('action' 'cite' 'classid' 'codebase' 'data' 'href' 'longdesc' 'profile' 'src' 'usemap')! !

!WAPrettyPrintedDocument methodsFor: 'configuration' stamp: 'lr 4/20/2007 21:14'!
knownTags
	^ #('a' 'abbr' 'acronym' 'address' 'area' 'b' 'base' 'bdo' 'big' 'blockquote' 'body' 'br' 'button' 'caption' 'cite' 'code' 'col' 'colgroup' 'dd' 'del' 'dfn' 'div' 'dl' 'dt' 'em' 'fieldset' 'form' 'h1' 'h2' 'h3' 'h4' 'h5' 'h6' 'head' 'hr' 'html' 'i' 'img' 'input' 'ins' 'ismap' 'kbd' 'label' 'legend' 'li' 'link' 'map' 'meta' 'noscript' 'object' 'ol' 'optgroup' 'option' 'p' 'param' 'pre' 'q' 'rb' 'rbc' 'rp' 'rt' 'rtc' 'ruby' 'samp' 'script' 'select' 'small' 'span' 'strong' 'style' 'sub' 'sup' 'table' 'tbody' 'td' 'textarea' 'tfoot' 'th' 'thead' 'title' 'tr' 'tt' 'ul' 'var')! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:39'!
nextPut: aCharacter
	self htmlEncoder nextPut: aCharacter! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:39'!
nextPutAll: aString
	self htmlEncoder nextPutAll: aString! !

!WAPrettyPrintedDocument methodsFor: 'writing-xhtml' stamp: 'lr 10/28/2007 14:42'!
openTag: aString attributes: anAttributes closed: aBoolean
	self indent.
	html text: '<'.
	html span
		class: (self cssClassFor: aString);
		with: aString.
	self attributes: anAttributes.
	aBoolean
		ifTrue: [ html text: '/' ].
	html text: '>'.
	aBoolean
		ifFalse: [ indentLevel := indentLevel + 1 ].
	indentCloseTags removeLast; addLast: true; addLast: aBoolean! !

!WAPrettyPrintedDocument methodsFor: 'writing' stamp: 'lr 5/11/2007 11:40'!
print: anObject
	self document print: anObject! !

!WAPrettyPrintedDocument methodsFor: 'load scripts' stamp: 'jf 1/23/2009 03:26'!
writeLoadScript: anObject
	html break; space; space; space.
	super writeLoadScript: anObject! !

!WAPrettyPrintedDocument methodsFor: 'actions' stamp: 'jf 1/23/2009 13:09'!
writeLoadScripts
	loadScripts isEmpty ifFalse: [ super writeLoadScripts ]! !

!WAPlatform methodsFor: '*seaside-development-core' stamp: 'jf 1/22/2009 02:11'!
walkbackClass
	"Answers the walkback class to be used by the web tools.
	http://code.google.com/p/seaside/issues/detail?id=1"
	self subclassResponsibility! !

WAFileLibrary subclass: #WADevelopmentFiles
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADevelopmentFiles commentStamp: 'jf 10/6/2008 21:27' prior: 0!
CSS and images used by the web-based development tools.

The icons are from the Tango Desktop Project (tango.freedesktop.org), they are licensed under the Creative Commons Attribution Share-Alike license.
!

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:58'!
codebrowserPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 9 22 18 55 41 59 82 2 72 0 0 1 203 73 68 65 84 56 203 165 147 77 104 19 65 20 199 127 51 221 163 72 22 34 45 226 177 224 41 160 88 43 1 15 130 21 132 120 236 69 208 182 39 175 165 23 21 60 138 32 197 32 245 34 126 128 154 22 138 49 189 91 26 17 77 92 16 237 193 98 211 141 27 76 253 192 213 108 235 16 21 90 145 205 120 48 67 179 109 106 43 190 203 255 13 204 251 207 111 102 222 131 255 12 97 146 226 93 250 128 25 224 216 86 122 120 136 188 169 147 0 151 71 47 157 1 102 14 30 119 216 142 182 18 88 77 189 1 240 237 249 57 182 163 87 79 74 221 172 59 45 141 211 222 84 64 89 21 88 221 147 167 172 10 252 232 122 216 86 95 76 75 6 199 138 28 233 31 6 24 55 4 196 227 113 196 137 165 63 139 125 77 101 77 125 223 39 127 79 50 116 237 25 31 158 140 51 183 16 132 64 135 213 122 31 165 20 245 122 125 195 75 7 65 128 155 73 173 21 123 203 124 45 77 117 0 61 17 3 219 182 177 109 59 82 236 251 62 110 38 197 224 88 145 197 199 25 94 149 151 81 165 28 64 207 200 100 99 246 175 4 230 228 129 116 129 197 124 134 185 183 10 85 202 241 115 255 69 206 159 189 48 11 136 77 9 180 214 20 210 189 12 92 121 138 55 125 135 202 231 239 168 249 7 188 239 26 166 179 205 55 70 8 180 214 100 179 89 126 201 67 204 59 14 239 62 213 89 122 61 5 189 105 118 173 172 0 218 52 161 110 75 16 134 33 187 63 166 121 244 165 155 251 185 28 221 242 37 59 251 110 145 76 38 113 93 151 55 149 5 140 139 92 79 80 173 86 241 60 143 145 201 6 71 59 43 172 238 72 16 30 24 37 145 72 96 89 22 150 101 69 186 120 3 65 44 22 67 107 77 173 86 67 107 141 148 18 173 53 66 8 132 16 173 219 27 17 3 165 20 142 227 108 58 117 198 100 125 24 131 137 155 183 175 159 250 135 41 158 48 201 111 90 157 232 152 121 9 252 18 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 19:44'!
configPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 4 11 55 32 209 169 238 103 0 0 0 29 116 69 88 116 67 111 109 109 101 110 116 0 67 114 101 97 116 101 100 32 119 105 116 104 32 84 104 101 32 71 73 77 80 239 100 37 110 0 0 1 217 73 68 65 84 56 203 197 147 77 107 19 97 20 133 159 105 107 131 52 157 52 35 161 38 67 55 129 198 221 132 100 66 72 138 88 117 37 53 89 137 8 21 4 33 100 254 65 17 92 117 33 136 43 17 55 45 253 3 165 45 8 67 178 81 12 88 65 145 188 249 152 162 130 219 36 148 137 52 37 89 180 136 31 113 97 103 72 219 116 213 133 119 117 121 207 229 112 239 57 231 133 115 150 116 22 240 244 217 147 190 211 63 90 122 124 230 220 152 211 220 189 119 39 163 235 113 19 64 136 74 22 32 159 51 88 93 91 57 134 157 36 115 9 116 61 110 230 115 6 150 101 1 152 161 160 74 203 110 16 10 170 160 99 166 146 105 52 77 3 232 15 146 140 13 178 89 150 197 165 105 63 183 179 11 238 91 44 17 37 70 212 197 79 214 168 211 248 21 191 248 211 255 189 24 185 50 75 171 209 98 251 221 118 175 109 183 61 59 214 78 111 202 55 229 153 240 78 80 42 149 16 162 146 253 242 249 235 183 99 27 56 130 133 130 42 0 181 90 173 103 219 223 95 9 81 221 84 20 229 170 36 141 62 92 200 220 10 56 231 232 122 220 213 98 196 97 202 231 12 98 137 127 171 250 124 62 185 217 108 110 110 172 111 153 157 78 231 189 44 123 3 206 57 249 156 49 220 133 213 181 21 66 65 149 88 34 202 193 193 225 225 220 92 122 9 32 28 14 27 221 110 183 7 200 213 114 157 194 110 241 180 6 111 94 191 93 246 43 126 49 57 233 93 188 113 237 38 63 127 253 184 208 110 183 3 145 200 236 3 73 226 242 252 245 121 121 220 51 78 69 84 16 162 146 125 241 252 229 253 161 54 166 146 105 90 118 3 117 70 69 157 81 47 30 65 178 51 147 74 166 1 204 141 245 45 215 198 145 193 117 52 77 99 207 222 167 96 22 169 150 235 0 84 203 117 10 102 145 61 123 223 201 193 112 13 142 84 237 187 73 212 49 51 211 25 10 187 69 39 153 230 199 79 31 78 37 241 220 127 225 255 215 95 179 89 175 43 2 12 187 45 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'pmm 1/1/2009 19:14'!
deprecatedPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 214 2 16 14 39 45 183 238 146 119 0 0 1 232 73 68 65 84 56 203 149 147 193 74 27 97 20 133 191 59 153 206 52 137 51 131 16 153 74 237 70 67 196 32 134 65 74 154 48 4 130 72 99 131 116 23 186 16 34 93 116 231 48 27 241 9 92 27 116 101 192 66 192 69 73 86 5 173 175 80 8 62 128 80 92 4 10 133 22 92 212 64 73 49 127 55 214 18 200 180 246 192 189 139 203 225 59 103 115 133 8 133 240 200 128 183 0 3 120 221 128 47 227 124 122 20 192 132 163 121 120 14 112 1 71 64 117 156 79 139 72 247 82 176 90 88 88 208 158 164 82 90 10 86 67 240 238 13 48 97 47 13 122 98 119 151 76 179 73 26 116 19 246 238 5 8 161 56 5 197 108 185 44 122 62 143 158 207 147 45 151 101 10 138 33 20 249 151 118 160 123 2 195 94 167 163 60 207 83 158 231 169 94 167 163 78 96 184 3 221 191 54 8 97 197 133 165 140 239 139 225 251 56 142 131 227 56 24 190 79 198 247 197 133 165 16 86 34 1 38 236 103 193 72 4 1 162 105 88 150 133 101 89 136 166 145 8 2 178 96 152 176 63 22 16 194 250 52 164 231 10 5 140 82 9 17 193 182 109 108 219 70 68 48 74 37 230 10 5 166 33 29 194 250 8 32 4 49 160 177 120 155 174 233 58 34 242 167 129 8 154 174 147 8 2 22 193 48 160 17 130 192 237 10 225 213 44 180 94 44 47 27 147 103 103 16 139 161 148 162 223 239 3 144 76 38 17 17 184 185 225 106 109 141 15 231 231 131 75 168 55 224 157 132 16 123 12 87 79 193 154 63 62 230 97 181 138 82 10 165 20 181 90 13 128 118 187 141 136 32 34 252 56 61 229 98 99 131 46 124 255 12 147 154 192 102 28 204 153 92 142 120 165 114 103 20 17 92 215 197 117 221 145 91 188 82 97 38 151 35 14 166 192 166 108 195 215 151 144 154 61 56 96 162 94 191 75 255 61 192 8 64 68 184 110 181 184 220 218 226 61 124 147 67 24 62 3 121 192 255 233 39 240 17 148 254 9 14 7 240 102 34 226 47 162 116 13 195 30 52 127 1 151 222 125 8 28 180 225 19 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'pmm 1/1/2009 19:24'!
haloCss
	^ '.halo {
	margin: 2px;
	border: 1px solid #aaa;
}

/* header */
.halo-header {
	overflow: hidden;
	padding: 2px;
	color: #444;
	background-color: #eee;
	border-bottom: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
.halo-header a {
	text-decoration: none;
}
.halo-header div {
	float: left;
}
.halo-header div.classnamehaloplugin,
.halo-header div.browserhaloplugin,
.halo-header div.inspectorplugin,
.halo-header div.styleshaloplugin {
	float: left;
	display: block;
	padding-right: 5px;
}
.halo-header div.browserhaloplugin, div.window-titlebar div.browserhaloplugin {
	background: url(codebrowser.png) no-repeat;
}
.halo-header div.inspectorplugin, div.window-titlebar div.inspectorplugin {
	background: url(inspector.png) no-repeat;
}
.halo-header div.styleshaloplugin, div.window-titlebar div.styleshaloplugin {
	background: url(styleeditor.png) no-repeat;
}
.halo-header div.browserhaloplugin a,
.halo-header div.inspectorplugin a,
.halo-header div.styleshaloplugin a {
	width: 16px;
	display: block;
	text-indent: -32000px;
	background-position: 0 50%;
	outline: none;
}
.halo-header div.modehaloplugin {
	float: right;
	display: block;
}
.halo-header div.modehaloplugin a {
	color: #444;
}
.halo-header div.modehaloplugin a:hover {
	color: #111;
}
.halo-header div.modehaloplugin a.active {
	font-weight: bold;
}
div.window-titlebar div.profilertoolplugin {
	background: url(profiler.png) no-repeat;
}
div.window-titlebar div.memorytoolplugin {
	background: url(memory.png) no-repeat;
}
div.window-titlebar div.configuretoolplugin {
	background: url(config.png) no-repeat;
}
div.window-titlebar div.deprecationtoolplugin {
	background: url(deprecated.png) no-repeat;
}

/* body */
.halo-body {
	clear: both;
	padding: 2px;
}

/* source */
.halo-source .tag-known {
	font-weight: bold;
	color: navy;
}
.halo-source .attribute-known {
	color: navy;
}
.halo-source .attribute-value {
	color: purple;
}
.halo-source .comment {
	font-style: italic;
	color: green;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:58'!
inspectorPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 240 0 240 0 239 52 6 103 27 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 11 5 16 15 5 37 253 173 47 0 0 1 246 73 68 65 84 56 203 157 146 77 107 19 81 24 133 159 59 201 36 77 154 102 134 74 82 10 10 181 93 104 26 69 20 193 133 184 20 10 85 119 226 38 191 192 111 169 244 31 136 182 36 65 68 20 116 89 119 85 16 197 77 168 59 65 236 162 84 40 164 137 86 171 150 80 53 141 205 71 39 77 50 51 215 69 72 73 66 82 170 103 119 15 239 61 239 225 188 71 60 121 250 120 49 247 39 119 140 61 64 85 213 231 19 183 38 47 182 144 211 209 187 150 220 35 238 77 223 145 237 162 78 41 235 92 62 191 185 235 118 77 211 59 242 78 33 196 206 35 153 76 118 28 10 133 66 93 133 119 28 180 15 102 50 25 102 95 204 2 144 152 75 0 208 180 107 119 7 223 190 175 146 74 167 57 122 106 140 109 197 139 105 43 184 100 133 212 252 107 38 110 223 140 196 162 247 159 53 254 40 237 14 52 93 35 149 78 115 232 228 24 159 11 94 6 7 2 140 28 8 82 18 62 180 209 113 252 154 62 115 237 198 149 227 93 29 36 230 18 12 135 79 179 82 112 115 233 204 16 190 30 21 211 182 81 29 10 239 150 37 193 35 227 54 75 111 22 0 1 160 116 10 75 122 3 12 13 232 88 182 100 219 52 169 212 44 202 85 139 126 159 155 95 101 181 37 9 69 74 137 148 118 75 48 110 183 11 132 160 92 181 168 214 36 155 91 53 220 170 131 253 253 30 164 16 45 93 112 2 182 105 154 45 78 108 99 131 53 163 138 223 163 162 247 185 176 45 137 223 227 228 211 70 129 125 61 150 157 107 114 174 212 43 234 66 211 116 52 77 231 194 185 243 164 23 222 18 236 19 124 249 153 39 155 43 145 55 42 124 92 89 167 84 174 144 91 122 229 44 21 139 63 26 2 34 26 159 154 177 44 43 210 124 13 195 48 112 56 84 78 156 141 176 188 86 100 203 84 24 236 149 172 47 190 100 248 224 8 0 31 230 223 167 30 62 120 116 88 116 107 216 213 235 151 167 2 129 224 100 51 231 235 245 17 30 13 243 59 155 173 247 101 245 43 130 127 68 44 30 149 13 145 255 18 0 148 88 60 106 1 148 13 131 191 6 140 246 211 127 51 231 46 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 19:44'!
memoryPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 213 10 19 17 58 52 159 194 36 103 0 0 1 240 73 68 65 84 56 203 165 147 61 104 20 65 24 134 159 221 153 157 221 189 194 20 34 18 209 75 97 12 66 208 72 2 1 33 96 97 115 96 17 36 106 180 17 82 88 137 193 70 17 15 46 133 164 176 178 49 130 149 86 134 147 72 136 88 156 66 42 27 65 68 61 73 180 9 130 7 241 206 52 10 130 119 59 127 22 49 49 33 39 74 124 225 101 186 103 158 225 251 38 40 149 138 15 128 115 108 35 222 251 105 74 165 162 111 181 154 190 217 106 250 191 197 57 231 51 157 173 183 84 42 122 185 70 155 184 59 79 185 82 253 167 155 71 11 135 185 112 162 7 0 9 16 69 138 114 165 138 234 0 37 99 136 20 103 142 46 67 16 50 251 166 11 156 7 60 24 139 54 134 114 165 202 248 233 62 0 194 141 100 21 167 68 105 202 217 161 58 23 135 7 17 74 146 38 9 105 46 69 37 41 34 151 144 36 9 0 214 152 223 6 107 17 42 70 36 49 253 61 123 8 115 5 250 187 27 168 232 19 143 23 14 32 188 3 35 201 66 13 128 177 118 171 65 148 40 70 6 107 236 219 213 193 203 165 6 93 249 83 136 72 146 36 49 81 162 16 113 132 138 213 159 13 78 14 212 8 3 137 200 21 224 219 44 65 48 130 144 130 171 199 159 179 80 223 141 179 14 235 44 83 111 3 140 109 3 184 60 122 157 128 128 143 181 25 222 47 127 37 191 23 14 229 119 114 164 211 48 216 55 142 247 0 158 169 251 183 218 3 110 207 220 68 40 129 148 17 66 10 62 55 230 232 221 63 202 195 215 53 204 247 59 88 99 177 198 254 122 130 221 10 120 242 174 155 40 85 168 88 17 197 10 33 63 112 176 243 25 190 89 35 12 2 158 46 245 210 252 145 1 139 237 13 96 117 222 22 71 232 29 206 57 46 61 234 192 249 29 104 109 208 86 99 113 171 6 27 1 90 103 140 13 15 112 111 238 213 38 220 226 60 192 139 182 155 184 242 101 101 179 193 149 243 67 92 27 59 134 214 25 89 43 67 27 141 214 107 231 134 26 77 163 81 95 135 73 96 122 114 242 198 246 127 227 255 230 39 112 67 0 83 217 168 244 129 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:59'!
profilerPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 4 115 66 73 84 8 8 8 8 124 8 100 136 0 0 0 9 112 72 89 115 0 0 4 157 0 0 4 157 1 124 52 107 161 0 0 0 25 116 69 88 116 83 111 102 116 119 97 114 101 0 119 119 119 46 105 110 107 115 99 97 112 101 46 111 114 103 155 238 60 26 0 0 3 25 73 68 65 84 56 141 101 147 79 104 219 117 24 198 63 223 111 218 181 105 27 243 167 165 127 213 181 22 35 181 171 237 198 152 204 22 230 193 169 200 14 67 24 84 152 135 194 16 188 8 66 17 113 243 44 115 189 120 16 65 135 5 157 90 240 160 224 230 182 67 41 108 172 44 235 97 3 219 117 90 211 218 37 105 154 52 77 211 52 77 242 203 239 251 199 131 53 108 250 192 115 123 223 207 203 3 239 35 172 181 60 170 177 209 113 25 104 14 156 10 132 90 94 110 244 53 29 208 74 233 236 230 230 189 108 58 115 253 171 111 63 185 202 127 36 30 5 188 59 246 241 96 248 64 223 55 62 191 127 64 169 138 168 171 3 173 20 219 185 50 78 197 213 249 173 252 157 244 218 218 91 95 127 255 233 234 255 0 227 239 157 127 59 220 223 247 89 93 67 77 176 183 219 71 103 48 129 150 65 124 161 126 42 21 205 159 75 113 230 34 247 217 217 113 210 235 177 216 169 139 151 206 223 168 2 206 156 254 176 249 224 139 135 127 243 135 188 29 195 71 2 120 202 119 168 245 182 83 44 149 8 118 190 134 244 120 81 74 145 201 100 185 118 121 150 100 114 251 143 116 34 49 48 57 53 81 145 0 79 247 118 127 39 106 100 199 161 161 30 230 102 127 165 232 212 163 157 36 30 247 47 246 213 122 144 82 34 165 36 24 244 51 114 236 32 96 194 77 1 255 231 0 114 108 116 92 120 27 26 15 181 181 122 233 122 178 131 55 222 252 128 153 217 24 209 165 251 56 187 15 1 133 16 226 159 188 66 208 209 217 194 11 131 61 212 213 213 31 5 144 66 136 103 129 64 40 244 4 198 24 16 130 177 119 206 177 190 219 207 236 92 148 197 197 69 172 181 143 185 185 37 136 54 170 125 108 116 188 94 122 106 106 142 26 107 106 125 190 122 86 86 163 104 173 81 74 113 226 228 25 86 182 70 184 114 245 38 174 235 98 173 197 24 67 98 45 134 223 223 132 209 38 4 246 57 169 149 138 56 101 199 221 201 151 120 170 107 127 21 176 177 177 129 197 195 240 240 8 214 90 180 214 24 99 104 111 235 36 159 47 0 228 64 44 73 107 237 239 21 167 146 201 110 230 80 74 85 125 225 194 4 199 143 191 194 208 208 32 90 235 170 141 49 100 82 89 132 144 201 201 169 137 162 156 156 154 176 197 194 238 194 194 252 67 50 153 44 74 41 92 215 229 236 217 143 8 135 195 184 174 91 133 106 173 201 109 21 184 125 123 30 167 84 140 0 72 128 92 38 115 122 183 224 108 220 186 113 143 157 157 66 117 120 59 159 163 92 46 85 33 197 221 50 215 126 185 9 200 196 149 235 63 156 171 2 38 167 38 74 15 22 238 126 17 141 166 203 63 253 56 67 34 190 177 119 85 163 181 65 107 67 124 53 205 165 201 203 36 83 185 98 36 50 125 49 182 22 13 10 33 164 176 214 34 132 104 4 122 7 250 142 188 62 252 210 171 239 123 27 26 219 189 245 251 232 238 105 163 226 104 150 151 227 184 174 182 249 252 86 106 122 230 231 47 227 201 149 8 240 0 88 174 118 65 8 225 7 158 169 173 217 183 255 240 208 177 147 173 173 157 207 55 183 180 117 25 173 77 42 21 95 79 165 18 75 119 231 111 77 91 107 215 128 5 32 102 173 181 143 181 113 239 227 26 129 16 224 7 124 123 49 139 64 1 200 0 219 214 90 243 239 206 223 67 200 195 25 126 17 209 190 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing' stamp: 'lr 1/7/2009 13:53'!
selectorsToInclude
	^ #( toolbarCss haloCss toolsCss windowCss )! !

!WADevelopmentFiles methodsFor: 'accessing-images' stamp: 'MAD 8/29/2008 18:59'!
styleeditorPng
	| cache |
	cache := #(nil) beMutable.
	(cache at: 1) isNil ifTrue: [
		cache at: 1 put: #(137 80 78 71 13 10 26 10 0 0 0 13 73 72 68 82 0 0 0 16 0 0 0 16 8 6 0 0 0 31 243 255 97 0 0 0 6 98 75 71 68 0 255 0 255 0 255 160 189 167 147 0 0 0 9 112 72 89 115 0 0 11 19 0 0 11 19 1 0 154 156 24 0 0 0 7 116 73 77 69 7 214 4 9 20 4 42 36 195 187 166 0 0 2 112 73 68 65 84 56 203 173 147 221 75 83 113 24 199 63 155 155 110 57 245 164 169 232 24 180 240 173 50 207 48 74 144 68 27 82 209 141 43 147 145 136 226 159 97 36 236 70 130 174 162 232 38 34 42 86 104 26 42 5 74 47 243 5 65 212 110 52 148 48 95 74 156 107 206 236 156 249 50 117 110 167 139 58 232 130 186 144 30 248 193 247 226 249 124 248 61 207 143 31 28 172 146 107 156 213 74 119 119 183 114 16 216 180 15 222 19 184 65 116 67 167 27 228 223 167 211 13 226 31 112 226 126 184 198 89 173 104 84 24 232 183 55 54 10 73 201 41 16 217 37 184 178 66 95 107 171 4 84 44 222 110 89 150 229 96 219 204 204 76 89 93 109 61 85 85 85 212 56 171 105 111 123 169 87 5 157 246 250 122 135 226 245 18 24 25 1 69 225 136 77 132 212 52 94 127 15 140 249 46 86 230 100 103 153 15 23 228 159 160 188 188 92 133 117 64 36 14 224 42 60 40 42 41 73 88 236 233 97 119 99 131 104 56 204 178 94 199 156 205 198 194 217 211 230 230 155 46 163 86 27 135 40 138 108 132 130 60 122 248 88 7 68 0 180 234 112 74 40 4 202 222 78 190 230 230 225 63 83 76 83 83 51 62 159 143 188 188 60 218 59 94 176 24 76 222 108 56 89 89 168 246 169 2 79 48 16 32 45 63 31 157 193 192 252 229 75 248 47 216 185 238 172 197 231 243 97 52 26 233 31 232 227 211 236 23 4 177 250 208 146 144 237 138 17 76 31 79 126 254 166 191 87 193 100 226 104 105 41 19 69 133 92 113 92 99 109 109 13 69 81 88 95 15 50 60 58 202 80 192 138 201 168 195 159 146 105 143 17 124 168 73 170 141 27 44 211 188 21 38 232 26 241 144 62 61 133 167 239 61 130 32 32 203 50 119 238 221 229 227 143 12 66 187 113 108 135 35 49 239 170 3 208 155 37 123 162 152 195 192 173 49 182 36 3 130 55 132 102 106 146 150 251 207 8 71 34 172 104 173 44 109 9 164 101 89 9 200 219 100 202 126 79 140 0 32 204 38 74 244 87 150 204 195 196 235 102 241 246 26 176 228 22 99 200 182 112 42 43 129 213 245 29 62 15 116 72 54 105 201 21 35 8 123 5 207 106 116 206 97 201 201 96 97 122 25 128 236 226 45 178 114 94 49 120 99 202 247 77 41 72 4 200 148 253 30 155 180 228 122 50 249 110 92 21 104 0 28 117 86 49 122 46 208 127 190 193 34 24 73 37 202 46 235 138 159 161 167 43 146 118 40 189 162 203 61 63 254 183 143 161 81 131 163 206 42 238 28 219 113 233 205 146 93 189 85 252 92 188 235 95 240 127 169 159 24 23 11 103 188 240 115 88 0 0 0 0 73 69 78 68 174 66 96 130) asByteArray ].
	^ cache at: 1! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 9/25/2008 17:53'!
toolbarCss
	^ 'body {
	margin-bottom: 25px;
}
#toolbar {
	z-index: 20;
	position: fixed;
	left: 0;
	right: 0;
	bottom: 0;
	padding: 2px;
	color: #444;
	background-color: #eee;
	border-top: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
#toolbar a {
	color: #444;
	padding-left: 3px;
	padding-right: 3px;
	text-decoration: none;
}
#toolbar a:hover {
	color: #111;
}
#toolbar a.deprecationtoolplugin {
	color: #ff7000;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 1/7/2009 13:53'!
toolsCss
	^ '.tool strong {
	color: #444444;
	font-family: Verdana, Arial, Helvetica, sans-serif;
	font-size: 12px;
	margin: 2px
}

.tool a, .tool a:link, .tool a:active, .tool a:visited, .tool a:focus, .tool a:hover {
	color:#008AFF;
	font-family: Helvetica, Verdana, Arial, sans-serif;
	font-size: 12px;
}

.tool table {
	border-collapse:collapse;
}

.tool table td {
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
	padding-left: 5px;
	padding-right: 5px;
}
	
.tool .right {
	text-align: right;
}'! !

!WADevelopmentFiles methodsFor: 'accessing-styles' stamp: 'lr 1/7/2009 13:53'!
windowCss
	^ '.window {
	margin: 1em;
	border: 1px solid #aaa;
}
.window .window-titlebar {
	color: #444;
	padding: 5px;
	overflow: hidden;
	background-color: #eee;
	border-bottom: 1px solid #aaa;
	font: 10pt Verdana, Arial, Helvetica, sans-serif;
}
.window .window-titlebar .window-title {
	float: left;
	font-weight: bold;
	padding-left: 20px;
}
.window .window-titlebar .window-close {
	float: right;
}
.window .window-titlebar .window-close a {
	color: #444;
	text-decoration: none;
}
.window .window-titlebar .window-close a:hover {
	color: #111;
}
.window .window-content {
	clear: both;
	padding: 2px;
	background-color: #fff;
}'! !

WARequestFilter subclass: #WADeprecatedToolFilter
	instanceVariableNames: 'notifications'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Filter'!

!WADeprecatedToolFilter methodsFor: 'actions' stamp: 'lr 12/30/2008 15:41'!
deprecated: aNotification
	"Adds a deprecated warning aNotification to the receiver. Remove old deprecation warnings that have the same message and detail text."

	notifications := notifications reject: [ :each | 
		(each messageText = aNotification messageText)
			and: [ each details = aNotification details ] ].
	notifications add: aNotification.
	aNotification resume! !

!WADeprecatedToolFilter methodsFor: 'processing' stamp: 'jf 1/14/2009 09:45'!
handleFiltered: aRequestContext
	[ super handleFiltered: aRequestContext ]
		on: WADeprecatedApi
		do: [ :notification | self deprecated: notification ]! !

!WADeprecatedToolFilter methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:25'!
initialize
	super initialize.
	self reset! !

!WADeprecatedToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:13'!
notifications
	^ notifications! !

!WADeprecatedToolFilter methodsFor: 'actions' stamp: 'lr 9/25/2008 15:12'!
reset
	notifications := OrderedCollection new! !

WARequestFilter subclass: #WATimingToolFilter
	instanceVariableNames: 'startTime previousTiming'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Filter'!

!WATimingToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:29'!
currentTiming
	"Answer the running timing, or 0 if no value is available."

	^ startTime isNil ifTrue: [ 0 ] ifFalse: [ Time millisecondsSince: startTime ]! !

!WATimingToolFilter methodsFor: 'processing' stamp: 'jf 1/14/2009 09:45'!
handleFiltered: aRequestContext
	startTime := Time millisecondClockValue.
	[ super handleFiltered: aRequestContext ]
		ensure: [ previousTiming := self currentTiming ]! !

!WATimingToolFilter methodsFor: 'accessing' stamp: 'lr 9/25/2008 15:29'!
previousTiming
	"Answer the previous timing, or 0 if no value is available."

	^ previousTiming ifNil: [ 0 ]! !

WAComponent subclass: #WAHalo
	instanceVariableNames: 'root mode plugins'
	classVariableNames: 'Halos'
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAHalo class methodsFor: 'instance creation' stamp: 'lr 5/11/2007 01:05'!
for: aComponent
	^ Halos at: aComponent ifAbsentPut: [ self new initializeOn: aComponent ]! !

!WAHalo class methodsFor: 'class initialization' stamp: 'jf 1/22/2009 02:43'!
initialize
	Halos := WAPlatform current weakDictionaryOfSize: 20! !

!WAHalo methodsFor: 'rendering' stamp: 'jf 10/21/2008 20:11'!
canHaveHalo
	^ false! !

!WAHalo methodsFor: 'initialization' stamp: 'lr 9/5/2007 11:46'!
initializeOn: aComponent
	root := aComponent.
	mode := WAValueHolder with: self modes first.
	plugins := WAHaloPlugin allSubclassesOn: self root for: self! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 12/6/2006 20:25'!
mode
	^ mode contents! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 12/6/2006 20:24'!
mode: aSymbol
	mode contents: aSymbol! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 3/26/2007 22:26'!
modes
	^ #( render: source: )! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 5/11/2007 01:06'!
plugins
	^ plugins! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'jf 1/23/2009 01:52'!
render: html
	self renderRootWithContext: html context! !

!WAHalo methodsFor: 'rendering' stamp: 'jf 10/7/2008 19:54'!
renderContentOn: html
	| haloHtml |
	haloHtml := self rendererClass context: html context.
	haloHtml div class: 'halo'; with: [
		haloHtml div class: 'halo-header'; with: [
			(self plugins select: [ :each | each isActive ])
				do: [ :each | html render: each ]
				separatedBy: [ html text: ' ' ] ].
		haloHtml div class: 'halo-body'; with: [
			self perform: self mode with: html ] ].
	haloHtml flush.
	html flush! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'jf 1/23/2009 01:55'!
renderRootWithContext: aRenderContext
	"This is a nasty hack.
	We don't want to go back through the RenderVisitor because	it will substitute
	the Halo of our root. Since that is us we get infinite recursion!!
	So we bypass the visitor by creating the root's renderer ourselves."
	
	self root renderContentOn: (self root rendererClass context: aRenderContext)! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 5/11/2007 09:39'!
root
	^ root! !

!WAHalo methodsFor: 'rendering-modes' stamp: 'jf 2/1/2009 22:31'!
source: html
	| context |
	html div class: 'halo-source'; with: [
		context := html context copy.
		context clearMode.

		context document: (WAPrettyPrintedDocument context: html context).
		self renderRootWithContext: context.
		context document close ]! !

!WAHalo methodsFor: 'accessing' stamp: 'lr 4/15/2007 18:50'!
states
	^ Array with: mode! !

WAComponent subclass: #WATool
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WATool commentStamp: 'pmm 10/11/2008 18:58' prior: 0!
A WATool is the common base class for tools called from the development tool bar. Is doesn't do anything but including WADevelopmentFiles.!

WATool subclass: #WADeprecation
	instanceVariableNames: 'table filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADeprecation class methodsFor: 'instance creation' stamp: 'obi 10/8/2008 20:21'!
on: filter
	^self new filter: filter; yourself! !

!WADeprecation methodsFor: 'private' stamp: 'lr 12/30/2008 15:36'!
buildTable
	^ WATableReport new
		rowPeriod: 1;
		rowColors: #( '#eee' 'white' );
		rows: self notifications;
		columns: (Array
			with: (WAReportColumn selector: #messageText title: 'Deprecated')
			with: (WAReportColumn selector: #details title: 'Details'))
		yourself! !

!WADeprecation methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:37'!
children
	^ Array with: self table! !

!WADeprecation methodsFor: 'accessing' stamp: 'obi 10/8/2008 20:20'!
filter: aFilter
	filter := aFilter! !

!WADeprecation methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:37'!
notifications
	^ filter notifications! !

!WADeprecation methodsFor: 'rendering' stamp: 'pmm 10/11/2008 18:52'!
renderContentOn: html
	html div
		class: 'tool';
		with: [
			html render: self table.
			html anchor
				callback: [ self resetDeprecationWarnings ];
				with: 'Reset deprecation warnings' ]
	! !

!WADeprecation methodsFor: 'actions' stamp: 'pmm 10/11/2008 18:30'!
resetDeprecationWarnings
	filter reset.
	self answer! !

!WADeprecation methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:37'!
table
	^ table ifNil: [ table := self buildTable ]! !

WATool subclass: #WAPluggableTool
	instanceVariableNames: 'component'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WAPluggableTool commentStamp: 'pmm 11/14/2008 22:28' prior: 0!
A WAPluggableTool is a wrapper component around tools that can't be made subclasses of WATool. WATool is only really needed to provide the icon image.

Instance Variables
	component:		<WAComponent>

component
	- the component to render
!

!WAPluggableTool class methodsFor: 'instance creation' stamp: 'pmm 11/14/2008 22:25'!
on: aComponent
	^self new
		initializeWith: aComponent;
		yourself! !

!WAPluggableTool methodsFor: 'accessing' stamp: 'pmm 11/14/2008 22:24'!
children
	^Array with: component! !

!WAPluggableTool methodsFor: 'initialization' stamp: 'pmm 11/14/2008 22:25'!
initializeWith: aComponent
	component := aComponent! !

!WATool methodsFor: 'updating' stamp: 'pmm 10/11/2008 18:53'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	WADevelopmentFiles default updateRoot: anHtmlRoot! !

WASystemConfiguration subclass: #WADevelopmentConfiguration
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Core'!

!WADevelopmentConfiguration methodsFor: 'description' stamp: 'jf 9/17/2008 20:13'!
describeOn: config
	config at: #rootDecorationClasses addAll: (Array with: WAToolDecoration).
	config at: #libraries addAll: (Array with: WADevelopmentFiles).
	config at: #exceptionHandler put: WAWalkbackErrorHandler! !

!WADevelopmentConfiguration methodsFor: 'description' stamp: 'jf 1/30/2009 17:40'!
parents
	^ Array with: WARenderLoopConfiguration instance! !

WAPlugin subclass: #WAHaloPlugin
	instanceVariableNames: ''
	classVariableNames: 'EnableSeasideTools'
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAHaloPlugin commentStamp: 'pmm 5/27/2007 07:47' prior: 0!
Abstract root class for all halo tools. They add functionality to the halo toolbar.!

WAHaloPlugin subclass: #WAClassnameHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAClassnameHaloPlugin commentStamp: 'pmm 5/27/2007 17:34' prior: 0!
I display the class name of the component class.!

!WAClassnameHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 100! !

!WAClassnameHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:58'!
renderContentOn: html
	html div class: self cssClass; with: self target className! !

!WAHaloPlugin class methodsFor: 'initialization' stamp: 'lr 5/11/2007 01:22'!
initialize
	EnableSeasideTools := true! !

!WAHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 12:22'!
renderContentOn: html
	html div
		class: self cssClass;
		with: [ super renderContentOn: html ]! !

WAHaloPlugin subclass: #WAModeHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAModeHaloPlugin commentStamp: 'pmm 5/27/2007 17:35' prior: 0!
I control the rendering modes of the halo.!

!WAModeHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 900! !

!WAModeHaloPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:58'!
renderContentOn: html
	html div class: self cssClass; with: [
		html text: '['.
		self requestor modes
			do: [ :each |
				html anchor
					class: 'active' if: self requestor mode = each;
					title: (self labelForSelector: each allButLast);
					callback: [ self requestor mode: each ];
					with: each first asUppercase ]
			separatedBy: [ html text: '|' ].
		html text: ']' ]! !

WAHaloPlugin subclass: #WAStylesHaloPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAStylesHaloPlugin commentStamp: 'pmm 5/27/2007 17:35' prior: 0!
I open the style editor on the component class.!

!WAStylesHaloPlugin methodsFor: 'actions' stamp: 'pmm 11/14/2008 22:26'!
execute
	EnableSeasideTools
		ifTrue: [ self open: (WAPluggableTool on: (WAViewer on: self target)) ]
		ifFalse: [ Browser fullOnClass: self target class selector: #style ]! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:56'!
label
	^ 'Styles'! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 11:02'!
priority
	^ 700! !

!WAStylesHaloPlugin methodsFor: 'accessing' stamp: 'pmm 5/16/2007 16:24'!
tooltip
	^ 'CSS Style Editor'! !

WAPlugin subclass: #WAToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAToolPlugin commentStamp: 'pmm 5/27/2007 07:47' prior: 0!
Abstract root class for all development tool bar tools.!

WAToolPlugin subclass: #WAConfigureToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAConfigureToolPlugin commentStamp: 'pmm 5/27/2007 18:33' prior: 0!
I display the configuration dialog for the currently active application!

!WAConfigureToolPlugin methodsFor: 'actions' stamp: 'pmm 11/14/2008 22:26'!
execute
	self open: (WAPluggableTool on: self application configurationComponent)! !

!WAConfigureToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:16'!
label
	^ 'Configure'! !

!WAConfigureToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 200! !

WAToolPlugin subclass: #WADeprecationToolPlugin
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WADeprecationToolPlugin commentStamp: 'pmm 5/27/2007 18:33' prior: 0!
I display deprecation warnings.!

!WADeprecationToolPlugin methodsFor: 'actions' stamp: 'pmm 10/11/2008 18:27'!
execute
	self open: (WADeprecation on: filter)! !

!WADeprecationToolPlugin methodsFor: 'initialization' stamp: 'lr 9/25/2008 11:24'!
initializeTarget: aTargetObject requestor: aRequestorObject
	super initializeTarget: aTargetObject requestor: aRequestorObject.
	self session addFilter: (filter := WADeprecatedToolFilter new)! !

!WADeprecationToolPlugin methodsFor: 'testing' stamp: 'lr 9/25/2008 15:14'!
isActive
	^ filter notifications notEmpty! !

!WADeprecationToolPlugin methodsFor: 'accessing' stamp: 'lr 12/30/2008 15:41'!
label
	^ 'Deprecated (' , filter notifications size printString , ')'! !

!WADeprecationToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 700! !

WAToolPlugin subclass: #WANewSessionToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WANewSessionToolPlugin commentStamp: 'pmm 5/27/2007 18:32' prior: 0!
I create a new session.!

!WANewSessionToolPlugin class methodsFor: 'accessing' stamp: 'pmm 5/10/2007 22:18'!
title
	^'New Session'! !

!WANewSessionToolPlugin methodsFor: 'actions' stamp: 'jf 10/18/2008 17:39'!
execute
	self session unregister.
	self requestContext redirectTo: self application baseUrl! !

!WANewSessionToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:26'!
label
	^ 'New Session'! !

!WANewSessionToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 100! !

WAToolPlugin subclass: #WATerminateToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WATerminateToolPlugin commentStamp: 'pmm 5/27/2007 18:32' prior: 0!
I try to terminate the process handling this session. This can work of you're at 100% CPU.!

!WATerminateToolPlugin methodsFor: 'testing' stamp: 'jf 1/30/2009 17:22'!
isActive
	^ self application preferenceAt: #sessionAllowTermination! !

!WATerminateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:29'!
label
	^ 'Terminate'! !

!WATerminateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:57'!
priority
	^ 600! !

!WATerminateToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html anchor
		url: (html context actionUrl
			withParameter: 'terminate');
		with: self label! !

WAToolPlugin subclass: #WATimingToolPlugin
	instanceVariableNames: 'filter'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WATimingToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I display render and callback times.!

!WATimingToolPlugin methodsFor: 'initialization' stamp: 'lr 9/25/2008 10:46'!
initializeTarget: aTargetObject requestor: aRequestorObject
	super initializeTarget: aTargetObject requestor: aRequestorObject.
	self session addFilter: (filter := WATimingToolFilter new)! !

!WATimingToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 900! !

!WATimingToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html span
		title: 'Callback Time';
		with: filter previousTiming.
	html text: '/'.
	html span
		title: 'Render Time';
		with: filter currentTiming.
	html text: ' ms'! !

WAToolPlugin subclass: #WAToggleHalosToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAToggleHalosToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I toggle halos on and off.!

!WAToggleHalosToolPlugin methodsFor: 'actions' stamp: 'lr 5/11/2007 13:54'!
execute
	 self requestor toggleHalos! !

!WAToggleHalosToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
label
	^ 'Toggle Halos'! !

!WAToggleHalosToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:56'!
priority
	^ 300! !

WAToolPlugin subclass: #WAValidateToolPlugin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Development-Plugins'!

!WAValidateToolPlugin commentStamp: 'pmm 5/27/2007 18:31' prior: 0!
I validate and XHTML page by sending it to the W3C validator. I only work if the website is publically available.!

!WAValidateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 00:30'!
label
	^ 'XHTML'! !

!WAValidateToolPlugin methodsFor: 'accessing' stamp: 'lr 5/11/2007 10:59'!
priority
	^ 800! !

!WAValidateToolPlugin methodsFor: 'rendering' stamp: 'jf 11/4/2008 11:59'!
renderContentOn: html
	html anchor
		title: 'Validate XHTML';
		url: 'http://validator.w3.org/check/referer';
		with: self label! !
WAHalo initialize!
WAHaloPlugin initialize!
